@@ -24,8 +24,10 @@
 #include "ui_mainwindow.h"
 
 #include <QDebug>
+#include <QDir>
 #include <QGuiApplication>
 #include <QFileDialog>
+#include <QFileInfo>
 #include <QInputDialog>
 #include <QKeyEvent>
 #include <QListWidget>
@@ -333,6 +335,29 @@ bool MainWindow::isWaylandSession()
     return !qgetenv("WAYLAND_DISPLAY").isEmpty();
 }
 
+bool MainWindow::isSystemdEnvironment() const
+{
+    if (chroot.isEmpty()) {
+        return QFile::exists(QStringLiteral("/run/systemd/system"));
+    }
+
+    const QString rootPath = tempDir.path();
+
+    const auto hasSystemdBinary = [&](const QString &relativePath) {
+        return QFile::exists(rootPath + relativePath);
+    };
+
+    QFileInfo initFile(rootPath + QStringLiteral("/sbin/init"));
+    if (initFile.exists()) {
+        const QString target = initFile.isSymLink() ? initFile.symLinkTarget() : initFile.canonicalFilePath();
+        if (target.contains(QLatin1String("systemd"), Qt::CaseInsensitive)) {
+            return true;
+        }
+    }
+
+    return false;
+}
+
 void MainWindow::appendLogWithColors(QTextEdit *textEdit, const QString &logContent)
 {
     // Regular expression to match ANSI escape sequences
@@ -1226,48 +1251,83 @@ void MainWindow::comboBootsplashToggled(bool checked)
 
 void MainWindow::pushLogClicked()
 {
-    // Determine base path based on chroot status
-    QString location = chroot.isEmpty() ? QString() : tempDir.path();
+    QString logContent;
+    QString fallbackLocation;
+    QString offlineJournalDir;
 
-    bool hasHush = kernelOptions.contains(hushTokenRx);
+    const bool systemdEnv = isSystemdEnvironment();
+    if (systemdEnv) {
+        QString journalctlCmd;
+        if (chroot.isEmpty()) {
+            journalctlCmd = QStringLiteral("journalctl -b --no-pager");
+        } else {
+            const QString rootPath = tempDir.path();
+            QString journalDir = rootPath + QStringLiteral("/var/log/journal");
+            if (!QDir(journalDir).exists()) {
+                journalDir = rootPath + QStringLiteral("/run/log/journal");
+            }
+            if (QDir(journalDir).exists()) {
+                offlineJournalDir = journalDir;
+                journalctlCmd = QStringLiteral("journalctl --directory=%1 -b --no-pager --root=%2")
+                                    .arg(journalDir, rootPath);
+            }
+        }
 
-    // Primary log location based on kernel options
-    location += hasHush ? "/run/rc.log" : "/var/log/boot.log";
-
-    // Fallback to alternate log location if primary doesn't exist
-    if (!QFile::exists(location)) {
-        location = chroot.isEmpty() ? "/var/log/boot" : tempDir.path() + "/var/log/boot";
+        if (!journalctlCmd.isEmpty()) {
+            logContent = cmd.getOutAsRoot(journalctlCmd, QuietMode::Yes);
+        }
     }
 
-    if (QFile::exists(location)) {
-        // Prepare command to remove formatting escape characters
-        // QString sedCommand = R"(sed 's/\x1b\[?([0-9]{1,2}(;[0-9]{1,2})*)?m?//g; s/\r//;')";
+    if (logContent.isEmpty()) {
+        QString location = chroot.isEmpty() ? QString() : tempDir.path();
+        const bool hasHush = kernelOptions.contains(hushTokenRx);
+        location += hasHush ? "/run/rc.log" : "/var/log/boot.log";
 
-        QString logContent = cmd.getOutAsRoot("cat " + location);
+        if (!QFile::exists(location)) {
+            location = chroot.isEmpty() ? "/var/log/boot" : tempDir.path() + "/var/log/boot";
+        }
 
-        // Create and configure the dialog to display the log
-        QDialog logDialog;
-        logDialog.setWindowTitle(tr("Boot Log"));
+        fallbackLocation = location;
 
-        auto *textEdit = new QTextEdit(&logDialog);
-        textEdit->setReadOnly(true);
-        textEdit->setMinimumSize(600, 500);
-        appendLogWithColors(textEdit, logContent);
-        // textEdit->setPlainText(logContent);
-
-        auto *closeButton = new QPushButton(tr("&Close"), &logDialog);
-        connect(closeButton, &QPushButton::clicked, &logDialog, &QDialog::accept);
-
-        auto *layout = new QVBoxLayout(&logDialog);
-        layout->addWidget(textEdit);
-        layout->addWidget(closeButton);
-
-        logDialog.setModal(true);
-        logDialog.setSizeGripEnabled(true);
-        logDialog.exec();
-    } else {
-        QMessageBox::critical(this, tr("Log not found"), tr("Could not find log at ") + location);
+        if (QFile::exists(location)) {
+            logContent = cmd.getOutAsRoot("cat " + location);
+        }
     }
+
+    if (logContent.isEmpty()) {
+        QString message;
+        if (systemdEnv) {
+            message = fallbackLocation.isEmpty()
+                ? tr("Could not read the systemd boot logs.")
+                : tr("Could not read the systemd boot logs%1 or the fallback log at %2.")
+                      .arg(offlineJournalDir.isEmpty() ? QString() : tr(" from %1").arg(offlineJournalDir),
+                           fallbackLocation);
+        } else {
+            message = fallbackLocation.isEmpty() ? tr("Could not find any boot logs.")
+                                                 : tr("Could not find log at %1").arg(fallbackLocation);
+        }
+        QMessageBox::critical(this, tr("Log not found"), message);
+        return;
+    }
+
+    QDialog logDialog;
+    logDialog.setWindowTitle(tr("Boot Log"));
+
+    auto *textEdit = new QTextEdit(&logDialog);
+    textEdit->setReadOnly(true);
+    textEdit->setMinimumSize(600, 500);
+    appendLogWithColors(textEdit, logContent);
+
+    auto *closeButton = new QPushButton(tr("&Close"), &logDialog);
+    connect(closeButton, &QPushButton::clicked, &logDialog, &QDialog::accept);
+
+    auto *layout = new QVBoxLayout(&logDialog);
+    layout->addWidget(textEdit);
+    layout->addWidget(closeButton);
+
+    logDialog.setModal(true);
+    logDialog.setSizeGripEnabled(true);
+    logDialog.exec();
 }
 
 void MainWindow::pushUefiClicked()
